@@ -1,12 +1,11 @@
 /*
  * bibtypes.c
  *
- * Copyright (c) Chris Putnam 2003-2010
+ * Copyright (c) Chris Putnam 2003-2013
  *
- * Program and source code released under the GPL
+ * Program and source code released under the GPL version 2
  *
  */
-
 #include <stdio.h>
 #include "fields.h"
 #include "reftypes.h"
@@ -25,7 +24,7 @@ static lookups article[] = {
 	{ "day",          "PARTDAY",   SIMPLE, LEVEL_MAIN },
 	{ "volume",       "VOLUME",    SIMPLE, LEVEL_MAIN },
 	{ "pages",        "PAGES",     PAGES,  LEVEL_MAIN },
-	{ "number",       "NUMBER",    SIMPLE, LEVEL_MAIN },
+	{ "number",       "ISSUE",     SIMPLE, LEVEL_MAIN },
 	{ "issue",        "ISSUE",     SIMPLE, LEVEL_MAIN },
 	{ "journal",      "TITLE",     TITLE,  LEVEL_HOST },
 	{ "publisher",    "PUBLISHER", SIMPLE, LEVEL_HOST },
@@ -34,25 +33,26 @@ static lookups article[] = {
 	{ "abstract",     "ABSTRACT",  SIMPLE, LEVEL_MAIN },
 	{ "contents",     "CONTENTS",  SIMPLE, LEVEL_MAIN },
 	{ "language",     "LANGUAGE",  SIMPLE, LEVEL_MAIN },
-	{ "note",         "NOTES",     SIMPLE, LEVEL_MAIN },
+	{ "note",         "NOTES",     BT_NOTE, LEVEL_MAIN },
 	{ "annote",       "ANNOTE",    SIMPLE, LEVEL_MAIN },
 	{ "location",     "LOCATION",  SIMPLE, LEVEL_MAIN },
-	{ "ftp",          "",      BIBTEX_URL, LEVEL_MAIN },
-	{ "url",          "",      BIBTEX_URL, LEVEL_MAIN },
+	{ "ftp",          "",      BT_URL, LEVEL_MAIN },
+	{ "url",          "",      BT_URL, LEVEL_MAIN },
 	{ "pdf",          "FILEATTACH",SIMPLE, LEVEL_MAIN },
-	{ "sentelink",    "FILEATTACH",BIBTEX_SENTE, LEVEL_MAIN },
-	{ "file",         "FILEATTACH",BIBTEX_FILE,  LEVEL_MAIN },
+	{ "sentelink",    "FILEATTACH",BT_SENTE, LEVEL_MAIN },
+	{ "file",         "FILEATTACH",LINKEDFILE,   LEVEL_MAIN },
 	{ "howpublished", "",       HOWPUBLISHED, LEVEL_MAIN },
 	{ "doi",          "DOI",       SIMPLE, LEVEL_MAIN },
 	{ "key",          "BIBKEY",       SIMPLE, LEVEL_MAIN },
 	{ "refnum",       "REFNUM",    SIMPLE, LEVEL_MAIN },
 	{ "crossref",     "CROSSREF",  SIMPLE, LEVEL_MAIN },
-	{ "keywords",     "KEYWORD",   SIMPLE, LEVEL_MAIN },
-	{ " ",            "INTERNAL_TYPE|ARTICLE",           ALWAYS, LEVEL_MAIN },
-	{ " ",            "ISSUANCE|continuing",    ALWAYS, LEVEL_HOST },
-	{ " ",            "RESOURCE|text",          ALWAYS, LEVEL_MAIN },
-	{ " ",            "GENRE|periodical",       ALWAYS, LEVEL_HOST },
-	{ " ",            "GENRE|academic journal", ALWAYS, LEVEL_HOST }
+	{ "keywords",     "KEYWORD",   KEYWORD, LEVEL_MAIN },
+	{ "",             "INTERNAL_TYPE|ARTICLE",           ALWAYS, LEVEL_MAIN },
+	{ "",             "ISSUANCE|continuing",     ALWAYS, LEVEL_HOST },
+	{ "",             "RESOURCE|text",           ALWAYS, LEVEL_MAIN },
+	{ "",             "NGENRE|journal article",  ALWAYS, LEVEL_MAIN },
+	{ "",             "GENRE|periodical",        ALWAYS, LEVEL_HOST },
+	{ "",             "NGENRE|academic journal", ALWAYS, LEVEL_HOST }
 };
 
 /* Book */
@@ -64,7 +64,7 @@ static lookups book[] = {
 	{ "booktitle",    "TITLE",     TITLE,  LEVEL_MAIN },
 	{ "series",       "TITLE",     TITLE,  LEVEL_HOST },
 	{ "publisher",    "PUBLISHER", SIMPLE, LEVEL_MAIN },
-	{ "organization", "AUTHOR:CORP", SIMPLE, LEVEL_MAIN },
+	{ "organization", "ORGANIZER:CORP", BT_ORG, LEVEL_MAIN },
 	{ "address",      "ADDRESS",   SIMPLE, LEVEL_MAIN },
 	{ "editor",       "EDITOR",    PERSON, LEVEL_MAIN },
 	{ "year",         "YEAR",      SIMPLE, LEVEL_MAIN },
@@ -79,26 +79,26 @@ static lookups book[] = {
 	{ "contents",     "CONTENTS",  SIMPLE, LEVEL_MAIN },
 	{ "language",     "LANGUAGE",  SIMPLE, LEVEL_MAIN },
 	{ "location",     "LOCATION",  SIMPLE, LEVEL_MAIN },
-	{ "note",         "NOTES",     SIMPLE, LEVEL_MAIN },
+	{ "note",         "NOTES",     BT_NOTE, LEVEL_MAIN },
 	{ "annote",       "ANNOTE",    SIMPLE, LEVEL_MAIN },
 	{ "type",         "GENRE",     SIMPLE, LEVEL_MAIN },
 	{ "key",          "BIBKEY",    SIMPLE, LEVEL_MAIN },
-	{ "ftp",          "",       BIBTEX_URL, LEVEL_MAIN },
-	{ "url",          "",       BIBTEX_URL, LEVEL_MAIN },
+	{ "ftp",          "",       BT_URL, LEVEL_MAIN },
+	{ "url",          "",       BT_URL, LEVEL_MAIN },
 	{ "pdf",          "FILEATTACH",SIMPLE, LEVEL_MAIN },
-	{ "sentelink",    "FILEATTACH",BIBTEX_SENTE, LEVEL_MAIN },
-	{ "file",         "FILEATTACH",BIBTEX_FILE,  LEVEL_MAIN },
-	{ "address"       "ADDRESS",   SIMPLE, LEVEL_MAIN },
+	{ "sentelink",    "FILEATTACH",BT_SENTE, LEVEL_MAIN },
+	{ "file",         "FILEATTACH",LINKEDFILE,   LEVEL_MAIN },
+	{ "address",      "ADDRESS",   SIMPLE, LEVEL_MAIN },
 	{ "howpublished", "",       HOWPUBLISHED, LEVEL_MAIN },
 	{ "doi",          "DOI",       SIMPLE, LEVEL_MAIN },
 	{ "refnum",       "REFNUM",    SIMPLE, LEVEL_MAIN },
 	{ "crossref",     "CROSSREF",  SIMPLE, LEVEL_MAIN },
-	{ "keywords",     "KEYWORD",   SIMPLE, LEVEL_MAIN },
+	{ "keywords",     "KEYWORD",   KEYWORD, LEVEL_MAIN },
 	{ "refnum",       "REFNUM",    SIMPLE, LEVEL_MAIN },
-	{ " ",            "INTERNAL_TYPE|BOOK",     ALWAYS, LEVEL_MAIN },
-	{ " ",            "RESOURCE|text", ALWAYS, LEVEL_MAIN },
-	{ " ",            "ISSUANCE|monographic", ALWAYS, LEVEL_MAIN },
-	{ " ",            "GENRE|book",    ALWAYS, LEVEL_MAIN }
+	{ "",             "INTERNAL_TYPE|BOOK",   ALWAYS, LEVEL_MAIN },
+	{ "",             "RESOURCE|text",        ALWAYS, LEVEL_MAIN },
+	{ "",             "ISSUANCE|monographic", ALWAYS, LEVEL_MAIN },
+	{ "",             "GENRE|book",           ALWAYS, LEVEL_MAIN }
 };
 
 /* Technical reports */
@@ -108,6 +108,7 @@ static lookups report[] = {
 	{ "translator",   "TRANSLATOR",PERSON, LEVEL_MAIN },
 	{ "title",        "TITLE",        TITLE,  LEVEL_MAIN },
 	{ "booktitle",    "TITLE",        TITLE,  LEVEL_MAIN },
+	{ "series",       "TITLE",        TITLE,  LEVEL_HOST },
 	{ "editor",       "EDITOR",       PERSON, LEVEL_MAIN },
 	{ "publisher",    "PUBLISHER",    SIMPLE, LEVEL_MAIN },
 	{ "institution",  "PUBLISHER",    SIMPLE, LEVEL_MAIN },
@@ -122,23 +123,23 @@ static lookups report[] = {
 	{ "contents",     "CONTENTS",     SIMPLE, LEVEL_MAIN },
 	{ "language",     "LANGUAGE",     SIMPLE, LEVEL_MAIN },
 	{ "location",     "LOCATION",     SIMPLE, LEVEL_MAIN },
-	{ "note",         "NOTES",        SIMPLE, LEVEL_MAIN },
+	{ "note",         "NOTES",        BT_NOTE, LEVEL_MAIN },
 	{ "annote",       "ANNOTE",    SIMPLE, LEVEL_MAIN },
 	{ "key",          "BIBKEY",          SIMPLE, LEVEL_MAIN },
 	{ "doi",          "DOI",          SIMPLE, LEVEL_MAIN },
-	{ "ftp",          "",          BIBTEX_URL, LEVEL_MAIN },
-	{ "url",          "",          BIBTEX_URL, LEVEL_MAIN },
+	{ "ftp",          "",          BT_URL, LEVEL_MAIN },
+	{ "url",          "",          BT_URL, LEVEL_MAIN },
 	{ "pdf",          "FILEATTACH",SIMPLE, LEVEL_MAIN },
-	{ "sentelink",    "FILEATTACH",BIBTEX_SENTE, LEVEL_MAIN },
-	{ "file",         "FILEATTACH",BIBTEX_FILE,  LEVEL_MAIN },
+	{ "sentelink",    "FILEATTACH",BT_SENTE, LEVEL_MAIN },
+	{ "file",         "FILEATTACH",LINKEDFILE,   LEVEL_MAIN },
 	{ "howpublished", "",          HOWPUBLISHED, LEVEL_MAIN },
 	{ "refnum",    "REFNUM",          SIMPLE, LEVEL_MAIN },
 	{ "crossref",     "CROSSREF",  SIMPLE, LEVEL_MAIN },
 	{ "type",      "GENRE",            SIMPLE, LEVEL_MAIN },
-	{ "keywords",     "KEYWORD",   SIMPLE, LEVEL_MAIN },
-	{ " ",         "INTERNAL_TYPE|REPORT",     ALWAYS, LEVEL_MAIN },
-	{ " ",         "RESOURCE|text",   ALWAYS, LEVEL_MAIN },
-	{ " ",         "GENRE|report",    ALWAYS, LEVEL_MAIN }
+	{ "keywords",     "KEYWORD",   KEYWORD, LEVEL_MAIN },
+	{ "",         "INTERNAL_TYPE|REPORT", ALWAYS, LEVEL_MAIN },
+	{ "",         "RESOURCE|text",        ALWAYS, LEVEL_MAIN },
+	{ "",         "GENRE|report",         ALWAYS, LEVEL_MAIN }
 };
 
 static lookups manual[] = {
@@ -148,7 +149,7 @@ static lookups manual[] = {
 	{ "booktitle", "TITLE",     TITLE,  LEVEL_MAIN },
 	{ "editor",    "EDITOR",    PERSON, LEVEL_MAIN },
 	{ "publisher", "PUBLISHER", SIMPLE, LEVEL_MAIN },
-	{ "organization", "AUTHOR:CORP", SIMPLE, LEVEL_MAIN },
+	{ "organization", "ORGANIZER:CORP", BT_ORG, LEVEL_MAIN },
 	{ "address",   "ADDRESS",   SIMPLE, LEVEL_MAIN },
 	{ "year",      "YEAR",      SIMPLE, LEVEL_MAIN },
 	{ "month",     "MONTH",     SIMPLE, LEVEL_MAIN },
@@ -159,23 +160,23 @@ static lookups manual[] = {
 	{ "abstract",  "ABSTRACT",  SIMPLE, LEVEL_MAIN },
 	{ "contents",  "CONTENTS",  SIMPLE, LEVEL_MAIN },
 	{ "location",     "LOCATION",     SIMPLE, LEVEL_MAIN },
-	{ "note",         "NOTES",        SIMPLE, LEVEL_MAIN },
+	{ "note",         "NOTES",        BT_NOTE, LEVEL_MAIN },
 	{ "annote",       "ANNOTE",    SIMPLE, LEVEL_MAIN },
 	{ "key",          "BIBKEY",          SIMPLE, LEVEL_MAIN },
 	{ "doi",       "DOI",       SIMPLE, LEVEL_MAIN },
-	{ "ftp",       "",       BIBTEX_URL, LEVEL_MAIN },
-	{ "url",       "",       BIBTEX_URL, LEVEL_MAIN },
+	{ "ftp",       "",       BT_URL, LEVEL_MAIN },
+	{ "url",       "",       BT_URL, LEVEL_MAIN },
 	{ "pdf",          "FILEATTACH",SIMPLE, LEVEL_MAIN },
-	{ "sentelink",    "FILEATTACH",BIBTEX_SENTE, LEVEL_MAIN },
-	{ "file",         "FILEATTACH",BIBTEX_FILE,  LEVEL_MAIN },
+	{ "sentelink",    "FILEATTACH",BT_SENTE, LEVEL_MAIN },
+	{ "file",         "FILEATTACH",LINKEDFILE,   LEVEL_MAIN },
 	{ "howpublished", "",    HOWPUBLISHED, LEVEL_MAIN },
 	{ "language",     "LANGUAGE",  SIMPLE, LEVEL_MAIN },
 	{ "refnum",    "REFNUM",    SIMPLE, LEVEL_MAIN },
 	{ "crossref",     "CROSSREF",  SIMPLE, LEVEL_MAIN },
-	{ "keywords",     "KEYWORD",   SIMPLE, LEVEL_MAIN },
-	{ " ",         "INTERNAL_TYPE|REPORT",       ALWAYS, LEVEL_MAIN },
-	{ " ",         "RESOURCE|text",     ALWAYS, LEVEL_MAIN },
-	{ " ",         "GENRE|instruction", ALWAYS, LEVEL_MAIN }
+	{ "keywords",     "KEYWORD",   KEYWORD, LEVEL_MAIN },
+	{ "",         "INTERNAL_TYPE|REPORT", ALWAYS, LEVEL_MAIN },
+	{ "",         "RESOURCE|text",        ALWAYS, LEVEL_MAIN },
+	{ "",         "GENRE|instruction",    ALWAYS, LEVEL_MAIN }
 };
 
 /* Part of a book (e.g. chapter or section) */
@@ -184,7 +185,7 @@ static lookups inbook[] = {
 	{ "author",    "AUTHOR",    PERSON, LEVEL_MAIN },
 	{ "translator",   "TRANSLATOR",PERSON, LEVEL_MAIN },
 	{ "editor",    "EDITOR",    PERSON, LEVEL_HOST },
-	{ "chapter",   "TITLE",     TITLE,  LEVEL_MAIN },
+	{ "chapter",   "CHAPTER",   SIMPLE, LEVEL_MAIN },
 	{ "title",     "TITLE",     TITLE,  LEVEL_HOST },
 	{ "booktitle", "TITLE",     TITLE,  LEVEL_HOST },
 	{ "series",    "TITLE",     TITLE,  LEVEL_SERIES },
@@ -204,23 +205,24 @@ static lookups inbook[] = {
 	{ "language",     "LANGUAGE",     SIMPLE, LEVEL_MAIN },
 	{ "location",     "LOCATION",     SIMPLE, LEVEL_HOST },
 	{ "doi",       "DOI",       SIMPLE, LEVEL_MAIN },
-	{ "ftp",       "",       BIBTEX_URL, LEVEL_MAIN },
-	{ "url",       "",       BIBTEX_URL, LEVEL_MAIN },
+	{ "ftp",       "",       BT_URL, LEVEL_MAIN },
+	{ "url",       "",       BT_URL, LEVEL_MAIN },
 	{ "pdf",          "FILEATTACH",SIMPLE, LEVEL_MAIN },
-	{ "sentelink",    "FILEATTACH",BIBTEX_SENTE, LEVEL_MAIN },
-	{ "file",         "FILEATTACH",BIBTEX_FILE,  LEVEL_MAIN },
+	{ "sentelink",    "FILEATTACH",BT_SENTE, LEVEL_MAIN },
+	{ "file",         "FILEATTACH",LINKEDFILE,   LEVEL_MAIN },
 	{ "howpublished", "",    HOWPUBLISHED, LEVEL_MAIN },
 	{ "refnum",    "REFNUM",    SIMPLE, LEVEL_MAIN },
 	{ "crossref",     "CROSSREF",  SIMPLE, LEVEL_MAIN },
 	{ "type",      "GENRE",      SIMPLE, LEVEL_MAIN },
-	{ "note",         "NOTES",        SIMPLE, LEVEL_MAIN },
+	{ "note",         "NOTES",        BT_NOTE, LEVEL_MAIN },
 	{ "annote",       "ANNOTE",    SIMPLE, LEVEL_MAIN },
 	{ "key",          "BIBKEY",          SIMPLE, LEVEL_MAIN },
-	{ "keywords",     "KEYWORD",   SIMPLE, LEVEL_MAIN },
-	{ " ",         "INTERNAL_TYPE|INBOOK",   ALWAYS, LEVEL_MAIN },
-	{ " ",         "RESOURCE|text", ALWAYS, LEVEL_MAIN },
-	{ " ",         "ISSUANCE|monographic", ALWAYS, LEVEL_HOST },
-	{ " ",         "GENRE|book",    ALWAYS, LEVEL_HOST }
+	{ "keywords",     "KEYWORD",   KEYWORD, LEVEL_MAIN },
+	{ "",         "INTERNAL_TYPE|INBOOK", ALWAYS, LEVEL_MAIN },
+	{ "",         "RESOURCE|text",        ALWAYS, LEVEL_MAIN },
+	{ "",         "ISSUANCE|monographic", ALWAYS, LEVEL_HOST },
+	{ "",         "NGENRE|book chapter",  ALWAYS, LEVEL_MAIN },
+	{ "",         "GENRE|book",           ALWAYS, LEVEL_HOST }
 };
 
 /* References of papers in conference proceedings */
@@ -232,8 +234,9 @@ static lookups inproceedings[] = {
 	{ "title",     "TITLE",     TITLE,  LEVEL_MAIN },
 	{ "booktitle", "TITLE",     TITLE,  LEVEL_HOST },
 	{ "series",    "TITLE",     TITLE,  LEVEL_SERIES },
+	{ "chapter",   "CHAPTER",   SIMPLE, LEVEL_MAIN },
 	{ "publisher", "PUBLISHER", SIMPLE, LEVEL_HOST },
-	{ "organization", "AUTHOR:CORP", SIMPLE, LEVEL_HOST },
+	{ "organization", "ORGANIZER:CORP", BT_ORG, LEVEL_HOST },
 	{ "address",   "ADDRESS",   SIMPLE, LEVEL_HOST },
 	{ "year",      "PARTYEAR",  SIMPLE, LEVEL_MAIN },
 	{ "month",     "PARTMONTH", SIMPLE, LEVEL_MAIN },
@@ -249,22 +252,22 @@ static lookups inproceedings[] = {
 	{ "paper",     "PAPER",     SIMPLE, LEVEL_MAIN },
 	{ "location",     "LOCATION",     SIMPLE, LEVEL_HOST },
 	{ "doi",       "DOI",       SIMPLE, LEVEL_MAIN },
-	{ "ftp",       "",       BIBTEX_URL, LEVEL_MAIN },
-	{ "url",       "",       BIBTEX_URL, LEVEL_MAIN },
+	{ "ftp",       "",       BT_URL, LEVEL_MAIN },
+	{ "url",       "",       BT_URL, LEVEL_MAIN },
 	{ "pdf",          "FILEATTACH",SIMPLE, LEVEL_MAIN },
-	{ "sentelink",    "FILEATTACH",BIBTEX_SENTE, LEVEL_MAIN },
-	{ "file",         "FILEATTACH",BIBTEX_FILE,  LEVEL_MAIN },
+	{ "sentelink",    "FILEATTACH",BT_SENTE, LEVEL_MAIN },
+	{ "file",         "FILEATTACH",LINKEDFILE,   LEVEL_MAIN },
 	{ "type",      "GENRE",      SIMPLE, LEVEL_MAIN },
-	{ "note",         "NOTES",        SIMPLE, LEVEL_MAIN },
+	{ "note",         "NOTES",        BT_NOTE, LEVEL_MAIN },
 	{ "annote",       "ANNOTE",    SIMPLE, LEVEL_MAIN },
 	{ "key",          "BIBKEY",          SIMPLE, LEVEL_MAIN },
 	{ "howpublished", "",    HOWPUBLISHED, LEVEL_MAIN },
 	{ "refnum",    "REFNUM",    SIMPLE, LEVEL_MAIN },
 	{ "crossref",     "CROSSREF",  SIMPLE, LEVEL_MAIN },
-	{ "keywords",     "KEYWORD",   SIMPLE, LEVEL_MAIN },
-	{ " ",         "INTERNAL_TYPE|INPROCEEDINGS",  ALWAYS, LEVEL_MAIN },
-	{ " ",         "RESOURCE|text",       ALWAYS, LEVEL_MAIN },
-	{ " ",         "GENRE|conference publication",   ALWAYS, LEVEL_HOST }
+	{ "keywords",     "KEYWORD",   KEYWORD, LEVEL_MAIN },
+	{ "",         "INTERNAL_TYPE|INPROCEEDINGS",  ALWAYS, LEVEL_MAIN },
+	{ "",         "RESOURCE|text",                ALWAYS, LEVEL_MAIN },
+	{ "",         "GENRE|conference publication", ALWAYS, LEVEL_HOST }
 };
 
 /* Used for a section of a book with its own title */
@@ -274,7 +277,7 @@ static lookups incollection[] = {
 	{ "translator",   "TRANSLATOR",PERSON, LEVEL_MAIN },
 	{ "editor",    "EDITOR",    PERSON, LEVEL_HOST },
 	{ "title",     "TITLE",     TITLE,  LEVEL_MAIN },
-	{ "chapter",   "TITLE",     TITLE,  LEVEL_MAIN },
+	{ "chapter",   "CHAPTER",   SIMPLE, LEVEL_MAIN },
 	{ "booktitle", "TITLE",     TITLE,  LEVEL_HOST },
 	{ "series",    "TITLE",     TITLE,  LEVEL_SERIES },
 	{ "publisher", "PUBLISHER", SIMPLE, LEVEL_HOST },
@@ -292,24 +295,24 @@ static lookups incollection[] = {
 	{ "contents",  "CONTENTS",  SIMPLE, LEVEL_HOST },
 	{ "language",     "LANGUAGE",     SIMPLE, LEVEL_MAIN },
 	{ "type",      "GENRE",      SIMPLE, LEVEL_MAIN },
-	{ "note",         "NOTES",        SIMPLE, LEVEL_MAIN },
+	{ "note",         "NOTES",        BT_NOTE, LEVEL_MAIN },
 	{ "annote",       "ANNOTE",    SIMPLE, LEVEL_MAIN },
 	{ "key",          "BIBKEY",          SIMPLE, LEVEL_MAIN },
 	{ "doi",       "DOI",       SIMPLE, LEVEL_MAIN },
-	{ "ftp",       "",       BIBTEX_URL, LEVEL_MAIN },
-	{ "url",       "",       BIBTEX_URL, LEVEL_MAIN },
+	{ "ftp",       "",       BT_URL, LEVEL_MAIN },
+	{ "url",       "",       BT_URL, LEVEL_MAIN },
 	{ "pdf",          "FILEATTACH",SIMPLE, LEVEL_MAIN },
-	{ "sentelink",    "FILEATTACH",BIBTEX_SENTE, LEVEL_MAIN },
-	{ "file",         "FILEATTACH",BIBTEX_FILE,  LEVEL_MAIN },
+	{ "sentelink",    "FILEATTACH",BT_SENTE, LEVEL_MAIN },
+	{ "file",         "FILEATTACH",LINKEDFILE,   LEVEL_MAIN },
 	{ "location",     "LOCATION",     SIMPLE, LEVEL_HOST },
 	{ "howpublished", "",    HOWPUBLISHED, LEVEL_MAIN },
 	{ "refnum",    "REFNUM",    SIMPLE, LEVEL_MAIN },
 	{ "crossref",     "CROSSREF",  SIMPLE, LEVEL_MAIN },
-	{ "keywords",     "KEYWORD",   SIMPLE, LEVEL_MAIN },
-	{ " ",         "INTERNAL_TYPE|INCOLLECTION",   ALWAYS, LEVEL_MAIN },
-	{ " ",         "RESOURCE|text", ALWAYS, LEVEL_MAIN },
-	{ " ",         "ISSUANCE|monographic", ALWAYS, LEVEL_MAIN },
-	{ " ",         "GENRE|collection",    ALWAYS, LEVEL_HOST }
+	{ "keywords",     "KEYWORD",   KEYWORD, LEVEL_MAIN },
+	{ "",         "INTERNAL_TYPE|INCOLLECTION", ALWAYS, LEVEL_MAIN },
+	{ "",         "RESOURCE|text",              ALWAYS, LEVEL_MAIN },
+	{ "",         "ISSUANCE|monographic",       ALWAYS, LEVEL_MAIN },
+	{ "",         "GENRE|collection",           ALWAYS, LEVEL_HOST }
 };
 
 /* Proceedings */
@@ -322,7 +325,7 @@ static lookups proceedings[] = {
 	{ "booktitle", "TITLE",     TITLE,  LEVEL_MAIN },
 	{ "series",    "TITLE",     TITLE,  LEVEL_HOST },
 	{ "publisher", "PUBLISHER", SIMPLE, LEVEL_MAIN },
-	{ "organization", "AUTHOR:CORP", SIMPLE, LEVEL_MAIN },
+	{ "organization", "ORGANIZER:CORP", BT_ORG, LEVEL_MAIN },
 	{ "address",   "ADDRESS",   SIMPLE, LEVEL_MAIN },
 	{ "year",      "YEAR",      SIMPLE, LEVEL_MAIN },
 	{ "month",     "MONTH",     SIMPLE, LEVEL_MAIN },
@@ -335,23 +338,23 @@ static lookups proceedings[] = {
 	{ "abstract",  "ABSTRACT",  SIMPLE, LEVEL_MAIN },
 	{ "contents",  "CONTENTS",  SIMPLE, LEVEL_MAIN },
 	{ "doi",       "DOI",       SIMPLE, LEVEL_MAIN },
-	{ "ftp",       "",       BIBTEX_URL, LEVEL_MAIN },
-	{ "url",       "",       BIBTEX_URL, LEVEL_MAIN },
+	{ "ftp",       "",       BT_URL, LEVEL_MAIN },
+	{ "url",       "",       BT_URL, LEVEL_MAIN },
 	{ "pdf",          "FILEATTACH",SIMPLE, LEVEL_MAIN },
-	{ "sentelink",    "FILEATTACH",BIBTEX_SENTE, LEVEL_MAIN },
-	{ "file",         "FILEATTACH",BIBTEX_FILE,  LEVEL_MAIN },
+	{ "sentelink",    "FILEATTACH",BT_SENTE, LEVEL_MAIN },
+	{ "file",         "FILEATTACH",LINKEDFILE,   LEVEL_MAIN },
 	{ "language",     "LANGUAGE",     SIMPLE, LEVEL_MAIN },
 	{ "howpublished", "",    HOWPUBLISHED, LEVEL_MAIN },
 	{ "location",     "LOCATION",     SIMPLE, LEVEL_MAIN },
-	{ "note",         "NOTES",        SIMPLE, LEVEL_MAIN },
+	{ "note",         "NOTES",        BT_NOTE, LEVEL_MAIN },
 	{ "annote",       "ANNOTE",    SIMPLE, LEVEL_MAIN },
 	{ "key",          "BIBKEY",          SIMPLE, LEVEL_MAIN },
 	{ "refnum",    "REFNUM",    SIMPLE, LEVEL_MAIN },
 	{ "crossref",     "CROSSREF",  SIMPLE, LEVEL_MAIN },
-	{ "keywords",     "KEYWORD",   SIMPLE, LEVEL_MAIN },
-	{ " ",         "INTERNAL_TYPE|PROCEEDINGS",    ALWAYS, LEVEL_MAIN },
-	{ " ",         "RESOURCE|text",       ALWAYS, LEVEL_MAIN },
-	{ " ",         "GENRE|conference publication",   ALWAYS, LEVEL_MAIN }
+	{ "keywords",     "KEYWORD",   KEYWORD, LEVEL_MAIN },
+	{ "",         "INTERNAL_TYPE|PROCEEDINGS",    ALWAYS, LEVEL_MAIN },
+	{ "",         "RESOURCE|text",                ALWAYS, LEVEL_MAIN },
+	{ "",         "GENRE|conference publication", ALWAYS, LEVEL_MAIN }
 };
 
 static lookups phds[] = {
@@ -366,25 +369,25 @@ static lookups phds[] = {
 	{ "abstract",  "ABSTRACT",  SIMPLE, LEVEL_MAIN },
 	{ "contents",  "CONTENTS",  SIMPLE, LEVEL_MAIN },
 	{ "doi",       "DOI",       SIMPLE, LEVEL_MAIN },
-	{ "ftp",       "",       BIBTEX_URL, LEVEL_MAIN },
-	{ "url",       "",       BIBTEX_URL, LEVEL_MAIN },
+	{ "ftp",       "",       BT_URL, LEVEL_MAIN },
+	{ "url",       "",       BT_URL, LEVEL_MAIN },
 	{ "pdf",          "FILEATTACH",SIMPLE, LEVEL_MAIN },
-	{ "sentelink",    "FILEATTACH",BIBTEX_SENTE, LEVEL_MAIN },
-	{ "file",         "FILEATTACH",BIBTEX_FILE,  LEVEL_MAIN },
+	{ "sentelink",    "FILEATTACH",BT_SENTE, LEVEL_MAIN },
+	{ "file",         "FILEATTACH",LINKEDFILE,   LEVEL_MAIN },
 	{ "howpublished", "" ,   HOWPUBLISHED, LEVEL_MAIN },
 	{ "language",     "LANGUAGE",     SIMPLE, LEVEL_MAIN },
 	{ "location",     "LOCATION",     SIMPLE, LEVEL_MAIN },
-	{ "note",         "NOTES",        SIMPLE, LEVEL_MAIN },
+	{ "note",         "NOTES",        BT_NOTE, LEVEL_MAIN },
 	{ "annote",       "ANNOTE",    SIMPLE, LEVEL_MAIN },
 	{ "key",          "BIBKEY",          SIMPLE, LEVEL_MAIN },
 	{ "type",         "GENRE",         SIMPLE, LEVEL_MAIN },
 	{ "refnum",    "REFNUM",    SIMPLE, LEVEL_MAIN },
 	{ "crossref",     "CROSSREF",  SIMPLE, LEVEL_MAIN },
-	{ "keywords",     "KEYWORD",   SIMPLE, LEVEL_MAIN },
-	{ " ",         "INTERNAL_TYPE|THESIS",   ALWAYS, LEVEL_MAIN },
-	{ " ",         "RESOURCE|text", ALWAYS, LEVEL_MAIN },
-	{ " ",         "GENRE|thesis",  ALWAYS, LEVEL_MAIN },
-	{ " ",         "GENRE|Ph.D. thesis",  ALWAYS, LEVEL_MAIN }
+	{ "keywords",     "KEYWORD",   KEYWORD, LEVEL_MAIN },
+	{ "",         "INTERNAL_TYPE|THESIS", ALWAYS,  LEVEL_MAIN },
+	{ "",         "RESOURCE|text",        ALWAYS,  LEVEL_MAIN },
+	{ "",         "GENRE|thesis",         ALWAYS,  LEVEL_MAIN },
+	{ "",         "NGENRE|Ph.D. thesis",  DEFAULT, LEVEL_MAIN }
 };
 
 static lookups masters[] = {
@@ -399,25 +402,25 @@ static lookups masters[] = {
 	{ "abstract",  "ABSTRACT",  SIMPLE, LEVEL_MAIN },
 	{ "contents",  "CONTENTS",  SIMPLE, LEVEL_MAIN },
 	{ "doi",       "DOI",       SIMPLE, LEVEL_MAIN },
-	{ "ftp",       "",       BIBTEX_URL, LEVEL_MAIN },
-	{ "url",       "",       BIBTEX_URL, LEVEL_MAIN },
+	{ "ftp",       "",       BT_URL, LEVEL_MAIN },
+	{ "url",       "",       BT_URL, LEVEL_MAIN },
 	{ "pdf",          "FILEATTACH",SIMPLE, LEVEL_MAIN },
-	{ "sentelink",    "FILEATTACH",BIBTEX_SENTE, LEVEL_MAIN },
-	{ "file",         "FILEATTACH",BIBTEX_FILE,  LEVEL_MAIN },
+	{ "sentelink",    "FILEATTACH",BT_SENTE, LEVEL_MAIN },
+	{ "file",         "FILEATTACH",LINKEDFILE,   LEVEL_MAIN },
 	{ "language",     "LANGUAGE",     SIMPLE, LEVEL_MAIN },
 	{ "location",     "LOCATION",     SIMPLE, LEVEL_MAIN },
-	{ "note",         "NOTES",        SIMPLE, LEVEL_MAIN },
+	{ "note",         "NOTES",        BT_NOTE, LEVEL_MAIN },
 	{ "annote",       "ANNOTE",    SIMPLE, LEVEL_MAIN },
 	{ "key",          "BIBKEY",          SIMPLE, LEVEL_MAIN },
 	{ "type",         "GENRE",         SIMPLE, LEVEL_MAIN },
 	{ "howpublished", "",    HOWPUBLISHED, LEVEL_MAIN },
 	{ "refnum",    "REFNUM",    SIMPLE, LEVEL_MAIN },
 	{ "crossref",     "CROSSREF",  SIMPLE, LEVEL_MAIN },
-	{ "keywords",     "KEYWORD",   SIMPLE, LEVEL_MAIN },
-	{ " ",         "INTERNAL_TYPE|THESIS",   ALWAYS, LEVEL_MAIN },
-	{ " ",         "RESOURCE|text", ALWAYS, LEVEL_MAIN },
-	{ " ",         "GENRE|thesis",  ALWAYS, LEVEL_MAIN },
-	{ " ",         "GENRE|Masters thesis",  ALWAYS, LEVEL_MAIN }
+	{ "keywords",     "KEYWORD",   KEYWORD, LEVEL_MAIN },
+	{ "",         "INTERNAL_TYPE|THESIS",  ALWAYS,  LEVEL_MAIN },
+	{ "",         "RESOURCE|text",         ALWAYS,  LEVEL_MAIN },
+	{ "",         "GENRE|thesis",          ALWAYS,  LEVEL_MAIN },
+	{ "",         "NGENRE|Masters thesis", DEFAULT, LEVEL_MAIN }
 };
 
 /* Unpublished */
@@ -436,23 +439,23 @@ static lookups unpublished[] = {
 	{ "abstract",  "ABSTRACT",  SIMPLE, LEVEL_MAIN },
 	{ "contents",  "CONTENTS",  SIMPLE, LEVEL_MAIN },
 	{ "doi",       "DOI",       SIMPLE, LEVEL_MAIN },
-	{ "ftp",       "",       BIBTEX_URL, LEVEL_MAIN },
-	{ "url",       "",       BIBTEX_URL, LEVEL_MAIN },
+	{ "ftp",       "",       BT_URL, LEVEL_MAIN },
+	{ "url",       "",       BT_URL, LEVEL_MAIN },
 	{ "pdf",          "FILEATTACH",SIMPLE, LEVEL_MAIN },
-	{ "sentelink",    "FILEATTACH",BIBTEX_SENTE, LEVEL_MAIN },
-	{ "file",         "FILEATTACH",BIBTEX_FILE,  LEVEL_MAIN },
+	{ "sentelink",    "FILEATTACH",BT_SENTE, LEVEL_MAIN },
+	{ "file",         "FILEATTACH",LINKEDFILE,   LEVEL_MAIN },
 	{ "language",     "LANGUAGE",     SIMPLE, LEVEL_MAIN },
 	{ "howpublished", "",    HOWPUBLISHED, LEVEL_MAIN },
 	{ "location",     "LOCATION",     SIMPLE, LEVEL_MAIN },
-	{ "note",         "NOTES",        SIMPLE, LEVEL_MAIN },
+	{ "note",         "NOTES",        BT_NOTE, LEVEL_MAIN },
 	{ "annote",       "ANNOTE",    SIMPLE, LEVEL_MAIN },
 	{ "key",          "BIBKEY",          SIMPLE, LEVEL_MAIN },
 	{ "refnum",    "REFNUM",    SIMPLE, LEVEL_MAIN },
 	{ "crossref",     "CROSSREF",  SIMPLE, LEVEL_MAIN },
-	{ "keywords",     "KEYWORD",   SIMPLE, LEVEL_MAIN },
-	{ " ",         "INTERNAL_TYPE|BOOK",       ALWAYS, LEVEL_MAIN },
-	{ " ",         "RESOURCE|text",   ALWAYS, LEVEL_MAIN },
-	{ " ",         "GENRE|unpublished",      ALWAYS, LEVEL_MAIN }
+	{ "keywords",     "KEYWORD",   KEYWORD, LEVEL_MAIN },
+	{ "",         "INTERNAL_TYPE|BOOK", ALWAYS, LEVEL_MAIN },
+	{ "",         "RESOURCE|text",      ALWAYS, LEVEL_MAIN },
+	{ "",         "GENRE|unpublished",  ALWAYS, LEVEL_MAIN }
 };
 
 /*
@@ -461,7 +464,7 @@ static lookups unpublished[] = {
 static lookups standard[] = {
 	{ "author",    "AUTHOR",    PERSON, LEVEL_MAIN },
 	{ "translator",   "TRANSLATOR",PERSON, LEVEL_MAIN },
-	{ "organization", "AUTHOR:CORP", SIMPLE, LEVEL_MAIN },
+	{ "organization", "ORGANIZER:CORP", BT_ORG, LEVEL_MAIN },
 	{ "institution", "AUTHOR:CORP", SIMPLE, LEVEL_MAIN },
 	{ "title",     "TITLE",     TITLE,  LEVEL_MAIN },
 	{ "booktitle", "TITLE",     TITLE,  LEVEL_MAIN },
@@ -476,11 +479,11 @@ static lookups standard[] = {
 	{ "abstract",  "ABSTRACT",  SIMPLE, LEVEL_MAIN },
 	{ "contents",  "CONTENTS",  SIMPLE, LEVEL_MAIN },
 	{ "doi",       "DOI",       SIMPLE, LEVEL_MAIN },
-	{ "ftp",       "",      BIBTEX_URL, LEVEL_MAIN },
-	{ "url",       "",      BIBTEX_URL, LEVEL_MAIN },
+	{ "ftp",       "",      BT_URL, LEVEL_MAIN },
+	{ "url",       "",      BT_URL, LEVEL_MAIN },
 	{ "pdf",          "FILEATTACH",SIMPLE, LEVEL_MAIN },
-	{ "sentelink",    "FILEATTACH",BIBTEX_SENTE, LEVEL_MAIN },
-	{ "file",         "FILEATTACH",BIBTEX_FILE,  LEVEL_MAIN },
+	{ "sentelink",    "FILEATTACH",BT_SENTE, LEVEL_MAIN },
+	{ "file",         "FILEATTACH",LINKEDFILE,   LEVEL_MAIN },
 	{ "howpublished", "",    HOWPUBLISHED, LEVEL_MAIN },
 	{ "language",     "LANGUAGE",     SIMPLE, LEVEL_MAIN },
 	{ "refnum",    "REFNUM",    SIMPLE, LEVEL_MAIN },
@@ -488,13 +491,13 @@ static lookups standard[] = {
 	{ "number",    "NUMBER",      TITLE,  LEVEL_MAIN },
 	{ "revision",  "REVISION",    TITLE,  LEVEL_MAIN },
 	{ "location",     "LOCATION",     SIMPLE, LEVEL_MAIN },
-	{ "note",         "NOTES",        SIMPLE, LEVEL_MAIN },
+	{ "note",         "NOTES",        BT_NOTE, LEVEL_MAIN },
 	{ "annote",       "ANNOTE",    SIMPLE, LEVEL_MAIN },
 	{ "key",          "BIBKEY",          SIMPLE, LEVEL_MAIN },
-	{ "keywords",     "KEYWORD",   SIMPLE, LEVEL_MAIN },
+	{ "keywords",     "KEYWORD",   KEYWORD, LEVEL_MAIN },
 	{ "crossref",     "CROSSREF",  SIMPLE, LEVEL_MAIN },
-	{ " ",         "RESOURCE|text",   ALWAYS, LEVEL_MAIN },
-	{ " ",         "INTERNAL_TYPE|STANDARD",    ALWAYS, LEVEL_MAIN }
+	{ "",         "RESOURCE|text",          ALWAYS, LEVEL_MAIN },
+	{ "",         "INTERNAL_TYPE|STANDARD", ALWAYS, LEVEL_MAIN }
 };
 
 /*
@@ -516,21 +519,21 @@ static lookups periodical[] = {
 	{ "number",       "NUMBER",      TITLE,  LEVEL_MAIN },
 	{ "contents",     "CONTENTS",    SIMPLE, LEVEL_MAIN },
 	{ "doi",          "DOI",         SIMPLE, LEVEL_MAIN },
-	{ "ftp",          "",        BIBTEX_URL, LEVEL_MAIN },
-	{ "url",          "",        BIBTEX_URL, LEVEL_MAIN },
+	{ "ftp",          "",        BT_URL, LEVEL_MAIN },
+	{ "url",          "",        BT_URL, LEVEL_MAIN },
 	{ "pdf",          "FILEATTACH",SIMPLE, LEVEL_MAIN },
-	{ "sentelink",    "FILEATTACH",BIBTEX_SENTE, LEVEL_MAIN },
-	{ "file",         "FILEATTACH",BIBTEX_FILE,  LEVEL_MAIN },
+	{ "sentelink",    "FILEATTACH",BT_SENTE, LEVEL_MAIN },
+	{ "file",         "FILEATTACH",LINKEDFILE,   LEVEL_MAIN },
 	{ "howpublished", "",         HOWPUBLISHED, LEVEL_MAIN },
 	{ "refnum",       "REFNUM",      SIMPLE, LEVEL_MAIN },
 	{ "language",     "LANGUAGE",    SIMPLE, LEVEL_MAIN },
-	{ "note",         "NOTES",       SIMPLE, LEVEL_MAIN },
+	{ "note",         "NOTES",       BT_NOTE, LEVEL_MAIN },
 	{ "annote",       "ANNOTE",    SIMPLE, LEVEL_MAIN },
-	{ "organization", "AUTHOR:CORP", SIMPLE, LEVEL_MAIN },
+	{ "organization", "ORGANIZER:CORP", BT_ORG, LEVEL_MAIN },
 	{ "crossref",     "CROSSREF",  SIMPLE, LEVEL_MAIN },
-	{ "keywords",     "KEYWORD",   SIMPLE, LEVEL_MAIN },
-	{ " ",            "RESOURCE|text",   ALWAYS, LEVEL_MAIN },
-	{ " ",            "GENRE|periodical",ALWAYS, LEVEL_MAIN }
+	{ "keywords",     "KEYWORD",   KEYWORD, LEVEL_MAIN },
+	{ "",            "RESOURCE|text",    ALWAYS, LEVEL_MAIN },
+	{ "",            "GENRE|periodical", ALWAYS, LEVEL_MAIN }
 };
 
 /*
@@ -555,23 +558,23 @@ static lookups patent[] = {
 	{ "language",  "LANGUAGE",  SIMPLE, LEVEL_MAIN },
 	{ "location",  "LOCATION",  SIMPLE, LEVEL_MAIN },
 	{ "nationality", "NATIONALITY", SIMPLE, LEVEL_MAIN },
-	{ "note",      "NOTES",     SIMPLE, LEVEL_MAIN },
+	{ "note",      "NOTES",     BT_NOTE, LEVEL_MAIN },
 	{ "annote",       "ANNOTE",    SIMPLE, LEVEL_MAIN },
 	{ "key",       "BIBKEY",       SIMPLE, LEVEL_MAIN },
 	{ "doi",       "DOI",       SIMPLE, LEVEL_MAIN },
-	{ "ftp",       "",      BIBTEX_URL, LEVEL_MAIN },
-	{ "url",       "",      BIBTEX_URL, LEVEL_MAIN },
+	{ "ftp",       "",      BT_URL, LEVEL_MAIN },
+	{ "url",       "",      BT_URL, LEVEL_MAIN },
 	{ "pdf",          "FILEATTACH",SIMPLE, LEVEL_MAIN },
-	{ "sentelink",    "FILEATTACH",BIBTEX_SENTE, LEVEL_MAIN },
-	{ "file",         "FILEATTACH",BIBTEX_FILE,  LEVEL_MAIN },
+	{ "sentelink",    "FILEATTACH",BT_SENTE, LEVEL_MAIN },
+	{ "file",         "FILEATTACH",LINKEDFILE,   LEVEL_MAIN },
 	{ "howpublished", "",    HOWPUBLISHED, LEVEL_MAIN },
 	{ "type",       "GENRE",     SIMPLE, LEVEL_MAIN },
 	{ "refnum",    "REFNUM",    SIMPLE, LEVEL_MAIN },
 	{ "crossref",     "CROSSREF",  SIMPLE, LEVEL_MAIN },
-	{ "keywords",     "KEYWORD",   SIMPLE, LEVEL_MAIN },
-	{ " ",         "RESOURCE|text",   ALWAYS, LEVEL_MAIN },
-	{ " ",         "INTERNAL_TYPE|PATENT",    ALWAYS, LEVEL_MAIN },
-	{ " ",         "GENRE|patent",    ALWAYS, LEVEL_MAIN },
+	{ "keywords",     "KEYWORD",   KEYWORD, LEVEL_MAIN },
+	{ "",         "RESOURCE|text",        ALWAYS, LEVEL_MAIN },
+	{ "",         "INTERNAL_TYPE|PATENT", ALWAYS, LEVEL_MAIN },
+	{ "",         "GENRE|patent",         ALWAYS, LEVEL_MAIN },
 };
 
 /*
@@ -580,7 +583,7 @@ static lookups patent[] = {
 static lookups electronic[] = {
 	{ "author",    "AUTHOR",    PERSON, LEVEL_MAIN },
 	{ "translator",   "TRANSLATOR",PERSON, LEVEL_MAIN },
-	{ "organization", "AUTHOR:CORP", SIMPLE, LEVEL_MAIN },
+	{ "organization", "ORGANIZER:CORP", BT_ORG, LEVEL_MAIN },
 	{ "title",     "TITLE",     TITLE,  LEVEL_MAIN },
 	{ "booktitle", "TITLE",     TITLE,  LEVEL_MAIN },
 	{ "publisher", "PUBLISHER", SIMPLE, LEVEL_MAIN },
@@ -593,22 +596,22 @@ static lookups electronic[] = {
 	{ "volume",    "VOLUME",    SIMPLE, LEVEL_MAIN },
 	{ "contents",  "CONTENTS",  SIMPLE, LEVEL_MAIN },
 	{ "doi",       "DOI",       SIMPLE, LEVEL_MAIN },
-	{ "ftp",       "",      BIBTEX_URL, LEVEL_MAIN },
-	{ "url",       "",      BIBTEX_URL, LEVEL_MAIN },
+	{ "ftp",       "",      BT_URL, LEVEL_MAIN },
+	{ "url",       "",      BT_URL, LEVEL_MAIN },
 	{ "pdf",          "FILEATTACH",SIMPLE, LEVEL_MAIN },
-	{ "sentelink",    "FILEATTACH",BIBTEX_SENTE, LEVEL_MAIN },
-	{ "file",         "FILEATTACH",BIBTEX_FILE,  LEVEL_MAIN },
+	{ "sentelink",    "FILEATTACH",BT_SENTE, LEVEL_MAIN },
+	{ "file",         "FILEATTACH",LINKEDFILE,   LEVEL_MAIN },
 	{ "howpublished", "",    HOWPUBLISHED, LEVEL_MAIN },
 	{ "refnum",    "REFNUM",    SIMPLE, LEVEL_MAIN },
 	{ "crossref",     "CROSSREF",  SIMPLE, LEVEL_MAIN },
 	{ "location",  "LOCATION",  SIMPLE, LEVEL_MAIN },
-	{ "note",      "NOTES",     SIMPLE, LEVEL_MAIN },
+	{ "note",      "NOTES",     BT_NOTE, LEVEL_MAIN },
 	{ "annote",       "ANNOTE",    SIMPLE, LEVEL_MAIN },
 	{ "key",       "BIBKEY",       SIMPLE, LEVEL_MAIN },
 	{ "language",  "LANGUAGE",  SIMPLE, LEVEL_MAIN },
-	{ "keywords",     "KEYWORD",   SIMPLE, LEVEL_MAIN },
-        { " ",  "RESOURCE|software, multimedia",    ALWAYS, LEVEL_MAIN },
-	{ " ",         "GENRE|electronic",       ALWAYS, LEVEL_MAIN },
+	{ "keywords",     "KEYWORD",   KEYWORD, LEVEL_MAIN },
+        { "",         "RESOURCE|software, multimedia", ALWAYS, LEVEL_MAIN },
+	{ "",         "GENRE|electronic",              ALWAYS, LEVEL_MAIN },
 };
 
 static lookups misc[] = {
@@ -617,7 +620,7 @@ static lookups misc[] = {
 	{ "title",     "TITLE",     TITLE,  LEVEL_MAIN },
 	{ "booktitle", "TITLE",     TITLE,  LEVEL_MAIN },
 	{ "publisher", "PUBLISHER", SIMPLE, LEVEL_MAIN },
-	{ "organization", "AUTHOR:CORP", SIMPLE, LEVEL_MAIN },
+	{ "organization", "ORGANIZER:CORP", BT_ORG, LEVEL_MAIN },
 	{ "pages",     "PAGES",     PAGES,  LEVEL_MAIN },
 	{ "address",   "ADDRESS",   SIMPLE, LEVEL_MAIN },
 	{ "editor",    "EDITOR",    PERSON, LEVEL_MAIN },
@@ -627,21 +630,21 @@ static lookups misc[] = {
 	{ "abstract",  "ABSTRACT",  SIMPLE, LEVEL_MAIN },
 	{ "contents",  "CONTENTS",  SIMPLE, LEVEL_MAIN },
 	{ "doi",       "DOI",       SIMPLE, LEVEL_MAIN },
-	{ "ftp",       "",      BIBTEX_URL, LEVEL_MAIN },
-	{ "url",       "",      BIBTEX_URL, LEVEL_MAIN },
-	{ "pdf",          "FILEATTACH",SIMPLE, LEVEL_MAIN },
-	{ "sentelink",    "FILEATTACH",BIBTEX_SENTE, LEVEL_MAIN },
-	{ "file",         "FILEATTACH",BIBTEX_FILE,  LEVEL_MAIN },
+	{ "ftp",       "",      BT_URL, LEVEL_MAIN },
+	{ "url",       "",      BT_URL, LEVEL_MAIN },
+	{ "pdf",       "FILEATTACH",   SIMPLE, LEVEL_MAIN },
+	{ "sentelink", "FILEATTACH",BT_SENTE, LEVEL_MAIN },
+	{ "file",      "FILEATTACH",LINKEDFILE,   LEVEL_MAIN },
 	{ "howpublished", "",    HOWPUBLISHED, LEVEL_MAIN },
-	{ "refnum",    "REFNUM",    SIMPLE, LEVEL_MAIN },
-	{ "crossref",     "CROSSREF",  SIMPLE, LEVEL_MAIN },
-	{ "location",  "LOCATION",  SIMPLE, LEVEL_MAIN },
-	{ "note",      "NOTES",     SIMPLE, LEVEL_MAIN },
-	{ "annote",       "ANNOTE",    SIMPLE, LEVEL_MAIN },
+	{ "refnum",    "REFNUM",       SIMPLE, LEVEL_MAIN },
+	{ "crossref",  "CROSSREF",     SIMPLE, LEVEL_MAIN },
+	{ "location",  "LOCATION",     SIMPLE, LEVEL_MAIN },
+	{ "note",      "NOTES",        BT_NOTE, LEVEL_MAIN },
+	{ "annote",    "ANNOTE",       SIMPLE, LEVEL_MAIN },
 	{ "key",       "BIBKEY",       SIMPLE, LEVEL_MAIN },
-	{ "language",  "LANGUAGE",  SIMPLE, LEVEL_MAIN },
-	{ "keywords",  "KEYWORD",   SIMPLE, LEVEL_MAIN },
-	{ " ",         "INTERNAL_TYPE|MISC",       ALWAYS, LEVEL_MAIN },
+	{ "language",  "LANGUAGE",     SIMPLE, LEVEL_MAIN },
+	{ "keywords",  "KEYWORD",      KEYWORD, LEVEL_MAIN },
+	{ "",          "INTERNAL_TYPE|MISC",       ALWAYS, LEVEL_MAIN },
 };
 
 #define ORIG(a) ( &(a[0]) )
@@ -656,10 +659,12 @@ variants bibtex_all[] = {
 	REFTYPE( "inbook", inbook ),
 	REFTYPE( "incollection", incollection ),
 	REFTYPE( "inconference", inproceedings ),
+	REFTYPE( "conference", inproceedings ),
 	REFTYPE( "inproceedings", inproceedings ),
 	REFTYPE( "manual", manual ),
 	REFTYPE( "mastersthesis", masters ),
 	REFTYPE( "misc", misc ),
+	REFTYPE( "online", misc ),
 	REFTYPE( "patent", patent ),
 	REFTYPE( "phdthesis", phds ),
 	REFTYPE( "periodical", periodical ),
