@@ -1,9 +1,9 @@
 /*
  * medin.h
  *
- * Copyright (c) Chris Putnam 2004-2009
+ * Copyright (c) Chris Putnam 2004-2014
  *
- * Program and source code released under the GPL
+ * Source code released under the GPL version 2
  *
  */
 #ifndef MEDIN_H
@@ -16,7 +16,6 @@
 
 extern int medin_readf( FILE *fp, char *buf, int bufsize, int *bufpos, newstr *line, newstr *reference, int *fcharset );
 extern int medin_processf( fields *medin, char *data, char *filename, long nref );
-extern void medin_convertf( fields *medin, fields *info, int reftype, int verbose, variants *all, int nall );
 
 extern void medin_initparams( param *p, const char *progname );
 
