@@ -1,9 +1,9 @@
 /*
  * risin.h
  *
- * Copyright (c) Chris Putnam 2003-2009
+ * Copyright (c) Chris Putnam 2003-2014
  *
- * Program and source code released under the GPL
+ * Source code released under the GPL version 2
  *
  */
 #ifndef RISIN_H
@@ -17,7 +17,7 @@
 extern int risin_readf( FILE *fp, char *buf, int bufsize, int *bufpos, newstr *line, newstr *reference, int *fcharset );
 extern int risin_processf( fields *risin, char *p, char *filename, long nref );
 extern int risin_typef( fields *risin, char *filename, int nref, param *p, variants *all, int nall );
-extern void risin_convertf( fields *risin, fields *info, int reftype, param *p, variants *all, int nall ); 
+extern int risin_convertf( fields *risin, fields *info, int reftype, param *p, variants *all, int nall ); 
 
 extern void risin_initparams( param *p, const char *progname );
 
