@@ -3,9 +3,9 @@
  *
  * process titles into title/subtitle pairs for MODS
  *
- * Copyright (c) Chris Putnam 2004-2010
+ * Copyright (c) Chris Putnam 2004-2014
  *
- * Source code released under the GPL
+ * Source code released under the GPL version 2
  *
  */
 #include <stdio.h>
@@ -16,12 +16,14 @@
 #include "title.h"
 #include "is_ws.h"
 
-void
+int
 title_process( fields *info, char *tag, char *data, int level, 
-						unsigned char nosplittitle )
+	unsigned char nosplittitle )
 {
 	newstr title, subtitle;
 	char *p, *q;
+	int status;
+
 	newstr_init( &title );
 	newstr_init( &subtitle );
 
@@ -42,17 +44,25 @@ title_process( fields *info, char *tag, char *data, int level,
 	}
 
 	if ( strncasecmp( "SHORT", tag, 5 ) ) {
-		if ( title.len>0 ) 
-			fields_add( info, "TITLE", title.data, level );
-		if ( subtitle.len>0 ) 
-			fields_add( info, "SUBTITLE", subtitle.data, level );
+		if ( title.len>0 ) {
+			status = fields_add( info, "TITLE", title.data, level );
+			if ( status!=FIELDS_OK ) return 0;
+		}
+		if ( subtitle.len>0 ) {
+			status = fields_add( info, "SUBTITLE", subtitle.data, level );
+			if ( status!=FIELDS_OK ) return 0;
+		}
 	} else {
-		if ( title.len>0 )
-			fields_add( info, "SHORTTITLE", title.data, level );
+		if ( title.len>0 ) {
+			status = fields_add( info, "SHORTTITLE", title.data, level );
+			if ( status!=FIELDS_OK ) return 0;
+		}
 		/* no SHORT-SUBTITLE! */
 	}
 
 	newstr_free( &subtitle );
 	newstr_free( &title );
+
+	return 1;
 }
 
