@@ -1,9 +1,9 @@
 /*
  * xml.h
  *
- * Copyright (c) Chris Putnam 2004-2009
+ * Copyright (c) Chris Putnam 2004-2013
  *
- * Source code released under the GPL
+ * Source code released under the GPL version 2
  *
  */
 #ifndef XML_H
@@ -31,8 +31,12 @@ extern char * xml_findstart( char *buffer, char *tag );
 extern char * xml_findend( char *buffer, char *tag );
 extern int xml_tagexact( xml *node, char *s );
 extern int xml_tag_attrib( xml *node, char *s, char *attrib, char *value );
+extern int xml_hasattrib( xml *node, char *attrib, char *value );
 extern void xml_free( xml *x );
 extern char * xml_tree( char *p, xml *onode );
+extern int xml_hasdata( xml *node );
+extern char * xml_data( xml *node );
+extern int xml_tagwithdata( xml *node, char *tag );
 
 extern char *xml_pns; /* global Namespace */
 
